========================================================
   beancount: Double-Entry Accounting from Text Files
========================================================

.. contents::
..
    1  Description
    2  Documentation
    3  Download & Installation
    4  Versions
    5  Filing Bugs
    6  Copyright and License
    7  Donations
    8  Sincerely, thank you.
    9  Author


Description
===========

A double-entry bookkeeping computer language that lets you define financial
transaction records in a text file, read them in memory, generate a variety of
reports from them, and provides a web interface.


Documentation
=============

Documentation can be read at:

  https://beancount.github.io/docs/

Documentation authoring happens on Google Docs, where you can contribute by
requesting access or commenting on individual documents. An index of all source
documents is available here:

  http://furius.ca/beancount/doc/index

There's a `mailing-list dedicated to Beancount
<https://groups.google.com/forum/#!forum/beancount>`_, please post questions
there, so others can share in the responses. More general discussions about
command-line accounting also occur on the `Ledger mailing-list
<https://groups.google.com/forum/#!forum/ledger-cli>`_ so you might be
interested in that group as well.


Download & Installation
=======================

You can obtain the source code from the official Git repository on Github:

  | https://github.com/beancount/beancount/

See the `Installing Beancount`__ document for more details.

__ http://furius.ca/beancount/doc/install


Versions
========

There are three versions

- **Version 3** (`branch v3 <http://github.com/beancount/beancount/tree/v3>`_):
  The current stable version of Beancount since June 2024. Use this. Note that
  this version is trimmed down from v2 and most of the tools the v2 branch
  included have been moved to their own independent projects on Github.

- **Version 2** (`branch v2 <http://github.com/beancount/beancount/tree/v2>`_):
  The previous stable version of Beancount, in maintenance mode from 2020 until
  2024 and now frozen and obsolete. This was a complete rewrite of the first
  version, which introduced a number of constraints and a new grammar and much
  more.

- **Version 1** (`branch v1 <http://github.com/beancount/beancount/tree/v1>`_):
  The original version of Beancount. Development on this version halted in 2013.
  This initial version was intended to be similar to and partially compatible
  with Ledger. Do not use this.


Filing Bugs
===========

Tickets can be filed at on the Github project page:

  https://github.com/beancount/beancount/issues


Copyright and License
=====================

Copyright (C) 2007-2024  Martin Blais.  All Rights Reserved.

This code is distributed under the terms of the "GNU GPLv2 only".
See COPYING file for details.


Donations
=========

Beancount has found itself being useful to many users, companies, and
foundations since I started it around 2007. I never ask for money, as my intent
with this project is to build something that is useful to me first, as well as
for others, in the simplest, most durable manner, and I believe in the genuinely
free and open stance of Open Source software. Though its ends are utilitarian -
it is about doing my own accounting in the first order - it is also a labor of
love and I take great pride in it, pride which has pushed me to add the polish
so that it would be usable and understandable by others. This is one of the rare
areas of my software practice where I can let my desire for perfection and
minimalism run untamed from the demands of time and external constraints.

Many people have asked where they can donate for the project. If you would like
to give back, you can send a donation via Wise (preferably):

    https://wise.com/share/martinb4019

or PayPal at:

    https://www.paypal.com/paypalme/misislavski

Your donation is always appreciated in any amount, and while the countless hours
spent on building this project are impossible to match, the impact of each
donation is much larger than its financial import. I truly appreciate every
person who offers one; software can be a lonely endeavour, and those donations
as well as words of appreciation keep reminding me of the positive impact my
side projects can have on others. I feel gratitude for all users of Beancount.

Thank you!


Author
======

Martin Blais <blais@furius.ca>
